"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionLagBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionLagBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionLagBucket.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionLagBucketEnum.ConversionLagBucket.V(0)
        UNKNOWN = ConversionLagBucketEnum.ConversionLagBucket.V(1)
        LESS_THAN_ONE_DAY = ConversionLagBucketEnum.ConversionLagBucket.V(2)
        ONE_TO_TWO_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(3)
        TWO_TO_THREE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(4)
        THREE_TO_FOUR_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(5)
        FOUR_TO_FIVE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(6)
        FIVE_TO_SIX_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(7)
        SIX_TO_SEVEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(8)
        SEVEN_TO_EIGHT_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(9)
        EIGHT_TO_NINE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(10)
        NINE_TO_TEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(11)
        TEN_TO_ELEVEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(12)
        ELEVEN_TO_TWELVE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(13)
        TWELVE_TO_THIRTEEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(14)
        THIRTEEN_TO_FOURTEEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(15)
        FOURTEEN_TO_TWENTY_ONE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(16)
        TWENTY_ONE_TO_THIRTY_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(17)
        THIRTY_TO_FORTY_FIVE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(18)
        FORTY_FIVE_TO_SIXTY_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(19)
        SIXTY_TO_NINETY_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(20)
    class ConversionLagBucket(metaclass=_ConversionLagBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionLagBucketEnum.ConversionLagBucket.V(0)
    UNKNOWN = ConversionLagBucketEnum.ConversionLagBucket.V(1)
    LESS_THAN_ONE_DAY = ConversionLagBucketEnum.ConversionLagBucket.V(2)
    ONE_TO_TWO_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(3)
    TWO_TO_THREE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(4)
    THREE_TO_FOUR_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(5)
    FOUR_TO_FIVE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(6)
    FIVE_TO_SIX_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(7)
    SIX_TO_SEVEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(8)
    SEVEN_TO_EIGHT_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(9)
    EIGHT_TO_NINE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(10)
    NINE_TO_TEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(11)
    TEN_TO_ELEVEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(12)
    ELEVEN_TO_TWELVE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(13)
    TWELVE_TO_THIRTEEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(14)
    THIRTEEN_TO_FOURTEEN_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(15)
    FOURTEEN_TO_TWENTY_ONE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(16)
    TWENTY_ONE_TO_THIRTY_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(17)
    THIRTY_TO_FORTY_FIVE_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(18)
    FORTY_FIVE_TO_SIXTY_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(19)
    SIXTY_TO_NINETY_DAYS = ConversionLagBucketEnum.ConversionLagBucket.V(20)
    def __init__(
        self,
    ) -> None: ...

global___ConversionLagBucketEnum = ConversionLagBucketEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductBiddingCategoryLevelEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ProductBiddingCategoryLevel(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ProductBiddingCategoryLevel.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(0)
        UNKNOWN = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(1)
        LEVEL1 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(2)
        LEVEL2 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(3)
        LEVEL3 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(4)
        LEVEL4 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(5)
        LEVEL5 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(6)
    class ProductBiddingCategoryLevel(metaclass=_ProductBiddingCategoryLevel):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(0)
    UNKNOWN = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(1)
    LEVEL1 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(2)
    LEVEL2 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(3)
    LEVEL3 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(4)
    LEVEL4 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(5)
    LEVEL5 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(6)
    def __init__(
        self,
    ) -> None: ...

global___ProductBiddingCategoryLevelEnum = ProductBiddingCategoryLevelEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LocalPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LocalPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LocalPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(0)
        UNKNOWN = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(1)
        DEAL_ID = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(2)
        DEAL_NAME = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(3)
        SUBTITLE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(4)
        DESCRIPTION = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(5)
        PRICE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(6)
        FORMATTED_PRICE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(7)
        SALE_PRICE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(8)
        FORMATTED_SALE_PRICE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(9)
        IMAGE_URL = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(10)
        ADDRESS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(11)
        CATEGORY = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(12)
        CONTEXTUAL_KEYWORDS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(13)
        FINAL_URLS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(14)
        FINAL_MOBILE_URLS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(15)
        TRACKING_URL = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(16)
        ANDROID_APP_LINK = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(17)
        SIMILAR_DEAL_IDS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(18)
        IOS_APP_LINK = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(19)
        IOS_APP_STORE_ID = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(20)
    class LocalPlaceholderField(metaclass=_LocalPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(0)
    UNKNOWN = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(1)
    DEAL_ID = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(2)
    DEAL_NAME = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(3)
    SUBTITLE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(4)
    DESCRIPTION = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(5)
    PRICE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(6)
    FORMATTED_PRICE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(7)
    SALE_PRICE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(8)
    FORMATTED_SALE_PRICE = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(9)
    IMAGE_URL = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(10)
    ADDRESS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(11)
    CATEGORY = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(12)
    CONTEXTUAL_KEYWORDS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(13)
    FINAL_URLS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(14)
    FINAL_MOBILE_URLS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(15)
    TRACKING_URL = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(16)
    ANDROID_APP_LINK = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(17)
    SIMILAR_DEAL_IDS = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(18)
    IOS_APP_LINK = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(19)
    IOS_APP_STORE_ID = LocalPlaceholderFieldEnum.LocalPlaceholderField.V(20)
    def __init__(
        self,
    ) -> None: ...

global___LocalPlaceholderFieldEnum = LocalPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupBidModifierErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupBidModifierError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdGroupBidModifierError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(0)
        UNKNOWN = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(1)
        CRITERION_ID_NOT_SUPPORTED = (
            AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(2)
        )
        CANNOT_OVERRIDE_OPTED_OUT_CAMPAIGN_CRITERION_BID_MODIFIER = (
            AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(3)
        )
    class AdGroupBidModifierError(metaclass=_AdGroupBidModifierError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(0)
    UNKNOWN = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(1)
    CRITERION_ID_NOT_SUPPORTED = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(
        2
    )
    CANNOT_OVERRIDE_OPTED_OUT_CAMPAIGN_CRITERION_BID_MODIFIER = (
        AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(3)
    )
    def __init__(
        self,
    ) -> None: ...

global___AdGroupBidModifierErrorEnum = AdGroupBidModifierErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.policy_pb2
import google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2
import google.ads.google_ads.v6.proto.enums.policy_review_status_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdAssetPolicySummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POLICY_TOPIC_ENTRIES_FIELD_NUMBER: builtins.int
    REVIEW_STATUS_FIELD_NUMBER: builtins.int
    APPROVAL_STATUS_FIELD_NUMBER: builtins.int
    review_status: google.ads.google_ads.v6.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = (
        ...
    )
    approval_status: google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = (
        ...
    )
    @property
    def policy_topic_entries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.policy_pb2.PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.policy_pb2.PolicyTopicEntry
            ]
        ] = ...,
        review_status: google.ads.google_ads.v6.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = ...,
        approval_status: google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

global___AdAssetPolicySummary = AdAssetPolicySummary



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MutateErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MutateError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MutateError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MutateErrorEnum.MutateError.V(0)
        UNKNOWN = MutateErrorEnum.MutateError.V(1)
        RESOURCE_NOT_FOUND = MutateErrorEnum.MutateError.V(3)
        ID_EXISTS_IN_MULTIPLE_MUTATES = MutateErrorEnum.MutateError.V(7)
        INCONSISTENT_FIELD_VALUES = MutateErrorEnum.MutateError.V(8)
        MUTATE_NOT_ALLOWED = MutateErrorEnum.MutateError.V(9)
        RESOURCE_NOT_IN_GOOGLE_ADS = MutateErrorEnum.MutateError.V(10)
        RESOURCE_ALREADY_EXISTS = MutateErrorEnum.MutateError.V(11)
        RESOURCE_DOES_NOT_SUPPORT_VALIDATE_ONLY = MutateErrorEnum.MutateError.V(12)
        RESOURCE_READ_ONLY = MutateErrorEnum.MutateError.V(13)
    class MutateError(metaclass=_MutateError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MutateErrorEnum.MutateError.V(0)
    UNKNOWN = MutateErrorEnum.MutateError.V(1)
    RESOURCE_NOT_FOUND = MutateErrorEnum.MutateError.V(3)
    ID_EXISTS_IN_MULTIPLE_MUTATES = MutateErrorEnum.MutateError.V(7)
    INCONSISTENT_FIELD_VALUES = MutateErrorEnum.MutateError.V(8)
    MUTATE_NOT_ALLOWED = MutateErrorEnum.MutateError.V(9)
    RESOURCE_NOT_IN_GOOGLE_ADS = MutateErrorEnum.MutateError.V(10)
    RESOURCE_ALREADY_EXISTS = MutateErrorEnum.MutateError.V(11)
    RESOURCE_DOES_NOT_SUPPORT_VALIDATE_ONLY = MutateErrorEnum.MutateError.V(12)
    RESOURCE_READ_ONLY = MutateErrorEnum.MutateError.V(13)
    def __init__(
        self,
    ) -> None: ...

global___MutateErrorEnum = MutateErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LandingPageView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    UNEXPANDED_FINAL_URL_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def unexpanded_final_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        unexpanded_final_url: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "unexpanded_final_url", b"unexpanded_final_url"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "resource_name",
            b"resource_name",
            "unexpanded_final_url",
            b"unexpanded_final_url",
        ],
    ) -> None: ...

global___LandingPageView = LandingPageView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RequestErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _RequestError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RequestError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = RequestErrorEnum.RequestError.V(0)
        UNKNOWN = RequestErrorEnum.RequestError.V(1)
        RESOURCE_NAME_MISSING = RequestErrorEnum.RequestError.V(3)
        RESOURCE_NAME_MALFORMED = RequestErrorEnum.RequestError.V(4)
        BAD_RESOURCE_ID = RequestErrorEnum.RequestError.V(17)
        INVALID_CUSTOMER_ID = RequestErrorEnum.RequestError.V(16)
        OPERATION_REQUIRED = RequestErrorEnum.RequestError.V(5)
        RESOURCE_NOT_FOUND = RequestErrorEnum.RequestError.V(6)
        INVALID_PAGE_TOKEN = RequestErrorEnum.RequestError.V(7)
        EXPIRED_PAGE_TOKEN = RequestErrorEnum.RequestError.V(8)
        INVALID_PAGE_SIZE = RequestErrorEnum.RequestError.V(22)
        REQUIRED_FIELD_MISSING = RequestErrorEnum.RequestError.V(9)
        IMMUTABLE_FIELD = RequestErrorEnum.RequestError.V(11)
        TOO_MANY_MUTATE_OPERATIONS = RequestErrorEnum.RequestError.V(13)
        CANNOT_BE_EXECUTED_BY_MANAGER_ACCOUNT = RequestErrorEnum.RequestError.V(14)
        CANNOT_MODIFY_FOREIGN_FIELD = RequestErrorEnum.RequestError.V(15)
        INVALID_ENUM_VALUE = RequestErrorEnum.RequestError.V(18)
        DEVELOPER_TOKEN_PARAMETER_MISSING = RequestErrorEnum.RequestError.V(19)
        LOGIN_CUSTOMER_ID_PARAMETER_MISSING = RequestErrorEnum.RequestError.V(20)
        VALIDATE_ONLY_REQUEST_HAS_PAGE_TOKEN = RequestErrorEnum.RequestError.V(21)
        CANNOT_RETURN_SUMMARY_ROW_FOR_REQUEST_WITHOUT_METRICS = (
            RequestErrorEnum.RequestError.V(29)
        )
        CANNOT_RETURN_SUMMARY_ROW_FOR_VALIDATE_ONLY_REQUESTS = (
            RequestErrorEnum.RequestError.V(30)
        )
        INCONSISTENT_RETURN_SUMMARY_ROW_VALUE = RequestErrorEnum.RequestError.V(31)
        TOTAL_RESULTS_COUNT_NOT_ORIGINALLY_REQUESTED = RequestErrorEnum.RequestError.V(
            32
        )
        RPC_DEADLINE_TOO_SHORT = RequestErrorEnum.RequestError.V(33)
    class RequestError(metaclass=_RequestError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = RequestErrorEnum.RequestError.V(0)
    UNKNOWN = RequestErrorEnum.RequestError.V(1)
    RESOURCE_NAME_MISSING = RequestErrorEnum.RequestError.V(3)
    RESOURCE_NAME_MALFORMED = RequestErrorEnum.RequestError.V(4)
    BAD_RESOURCE_ID = RequestErrorEnum.RequestError.V(17)
    INVALID_CUSTOMER_ID = RequestErrorEnum.RequestError.V(16)
    OPERATION_REQUIRED = RequestErrorEnum.RequestError.V(5)
    RESOURCE_NOT_FOUND = RequestErrorEnum.RequestError.V(6)
    INVALID_PAGE_TOKEN = RequestErrorEnum.RequestError.V(7)
    EXPIRED_PAGE_TOKEN = RequestErrorEnum.RequestError.V(8)
    INVALID_PAGE_SIZE = RequestErrorEnum.RequestError.V(22)
    REQUIRED_FIELD_MISSING = RequestErrorEnum.RequestError.V(9)
    IMMUTABLE_FIELD = RequestErrorEnum.RequestError.V(11)
    TOO_MANY_MUTATE_OPERATIONS = RequestErrorEnum.RequestError.V(13)
    CANNOT_BE_EXECUTED_BY_MANAGER_ACCOUNT = RequestErrorEnum.RequestError.V(14)
    CANNOT_MODIFY_FOREIGN_FIELD = RequestErrorEnum.RequestError.V(15)
    INVALID_ENUM_VALUE = RequestErrorEnum.RequestError.V(18)
    DEVELOPER_TOKEN_PARAMETER_MISSING = RequestErrorEnum.RequestError.V(19)
    LOGIN_CUSTOMER_ID_PARAMETER_MISSING = RequestErrorEnum.RequestError.V(20)
    VALIDATE_ONLY_REQUEST_HAS_PAGE_TOKEN = RequestErrorEnum.RequestError.V(21)
    CANNOT_RETURN_SUMMARY_ROW_FOR_REQUEST_WITHOUT_METRICS = (
        RequestErrorEnum.RequestError.V(29)
    )
    CANNOT_RETURN_SUMMARY_ROW_FOR_VALIDATE_ONLY_REQUESTS = (
        RequestErrorEnum.RequestError.V(30)
    )
    INCONSISTENT_RETURN_SUMMARY_ROW_VALUE = RequestErrorEnum.RequestError.V(31)
    TOTAL_RESULTS_COUNT_NOT_ORIGINALLY_REQUESTED = RequestErrorEnum.RequestError.V(32)
    RPC_DEADLINE_TOO_SHORT = RequestErrorEnum.RequestError.V(33)
    def __init__(
        self,
    ) -> None: ...

global___RequestErrorEnum = RequestErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdErrorEnum.AdError.V(0)
        UNKNOWN = AdErrorEnum.AdError.V(1)
        AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE = AdErrorEnum.AdError.V(2)
        APPROXIMATELY_TOO_LONG = AdErrorEnum.AdError.V(3)
        APPROXIMATELY_TOO_SHORT = AdErrorEnum.AdError.V(4)
        BAD_SNIPPET = AdErrorEnum.AdError.V(5)
        CANNOT_MODIFY_AD = AdErrorEnum.AdError.V(6)
        CANNOT_SET_BUSINESS_NAME_IF_URL_SET = AdErrorEnum.AdError.V(7)
        CANNOT_SET_FIELD = AdErrorEnum.AdError.V(8)
        CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET = AdErrorEnum.AdError.V(9)
        CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING = AdErrorEnum.AdError.V(10)
        CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE = AdErrorEnum.AdError.V(11)
        CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING = AdErrorEnum.AdError.V(12)
        CANNOT_SET_URL = AdErrorEnum.AdError.V(13)
        CANNOT_SET_WITHOUT_FINAL_URLS = AdErrorEnum.AdError.V(14)
        CANNOT_SET_WITH_FINAL_URLS = AdErrorEnum.AdError.V(15)
        CANNOT_SET_WITH_URL_DATA = AdErrorEnum.AdError.V(17)
        CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR = AdErrorEnum.AdError.V(18)
        CUSTOMER_NOT_APPROVED_MOBILEADS = AdErrorEnum.AdError.V(19)
        CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS = AdErrorEnum.AdError.V(20)
        CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS = AdErrorEnum.AdError.V(21)
        CUSTOMER_NOT_ELIGIBLE = AdErrorEnum.AdError.V(22)
        CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL = AdErrorEnum.AdError.V(23)
        DIMENSION_ALREADY_IN_UNION = AdErrorEnum.AdError.V(24)
        DIMENSION_MUST_BE_SET = AdErrorEnum.AdError.V(25)
        DIMENSION_NOT_IN_UNION = AdErrorEnum.AdError.V(26)
        DISPLAY_URL_CANNOT_BE_SPECIFIED = AdErrorEnum.AdError.V(27)
        DOMESTIC_PHONE_NUMBER_FORMAT = AdErrorEnum.AdError.V(28)
        EMERGENCY_PHONE_NUMBER = AdErrorEnum.AdError.V(29)
        EMPTY_FIELD = AdErrorEnum.AdError.V(30)
        FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID = AdErrorEnum.AdError.V(31)
        FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH = AdErrorEnum.AdError.V(32)
        ILLEGAL_AD_CUSTOMIZER_TAG_USE = AdErrorEnum.AdError.V(33)
        ILLEGAL_TAG_USE = AdErrorEnum.AdError.V(34)
        INCONSISTENT_DIMENSIONS = AdErrorEnum.AdError.V(35)
        INCONSISTENT_STATUS_IN_TEMPLATE_UNION = AdErrorEnum.AdError.V(36)
        INCORRECT_LENGTH = AdErrorEnum.AdError.V(37)
        INELIGIBLE_FOR_UPGRADE = AdErrorEnum.AdError.V(38)
        INVALID_AD_ADDRESS_CAMPAIGN_TARGET = AdErrorEnum.AdError.V(39)
        INVALID_AD_TYPE = AdErrorEnum.AdError.V(40)
        INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE = AdErrorEnum.AdError.V(41)
        INVALID_ATTRIBUTES_FOR_MOBILE_TEXT = AdErrorEnum.AdError.V(42)
        INVALID_CALL_TO_ACTION_TEXT = AdErrorEnum.AdError.V(43)
        INVALID_CHARACTER_FOR_URL = AdErrorEnum.AdError.V(44)
        INVALID_COUNTRY_CODE = AdErrorEnum.AdError.V(45)
        INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG = AdErrorEnum.AdError.V(47)
        INVALID_INPUT = AdErrorEnum.AdError.V(48)
        INVALID_MARKUP_LANGUAGE = AdErrorEnum.AdError.V(49)
        INVALID_MOBILE_CARRIER = AdErrorEnum.AdError.V(50)
        INVALID_MOBILE_CARRIER_TARGET = AdErrorEnum.AdError.V(51)
        INVALID_NUMBER_OF_ELEMENTS = AdErrorEnum.AdError.V(52)
        INVALID_PHONE_NUMBER_FORMAT = AdErrorEnum.AdError.V(53)
        INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID = AdErrorEnum.AdError.V(54)
        INVALID_TEMPLATE_DATA = AdErrorEnum.AdError.V(55)
        INVALID_TEMPLATE_ELEMENT_FIELD_TYPE = AdErrorEnum.AdError.V(56)
        INVALID_TEMPLATE_ID = AdErrorEnum.AdError.V(57)
        LINE_TOO_WIDE = AdErrorEnum.AdError.V(58)
        MISSING_AD_CUSTOMIZER_MAPPING = AdErrorEnum.AdError.V(59)
        MISSING_ADDRESS_COMPONENT = AdErrorEnum.AdError.V(60)
        MISSING_ADVERTISEMENT_NAME = AdErrorEnum.AdError.V(61)
        MISSING_BUSINESS_NAME = AdErrorEnum.AdError.V(62)
        MISSING_DESCRIPTION1 = AdErrorEnum.AdError.V(63)
        MISSING_DESCRIPTION2 = AdErrorEnum.AdError.V(64)
        MISSING_DESTINATION_URL_TAG = AdErrorEnum.AdError.V(65)
        MISSING_LANDING_PAGE_URL_TAG = AdErrorEnum.AdError.V(66)
        MISSING_DIMENSION = AdErrorEnum.AdError.V(67)
        MISSING_DISPLAY_URL = AdErrorEnum.AdError.V(68)
        MISSING_HEADLINE = AdErrorEnum.AdError.V(69)
        MISSING_HEIGHT = AdErrorEnum.AdError.V(70)
        MISSING_IMAGE = AdErrorEnum.AdError.V(71)
        MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS = AdErrorEnum.AdError.V(72)
        MISSING_MARKUP_LANGUAGES = AdErrorEnum.AdError.V(73)
        MISSING_MOBILE_CARRIER = AdErrorEnum.AdError.V(74)
        MISSING_PHONE = AdErrorEnum.AdError.V(75)
        MISSING_REQUIRED_TEMPLATE_FIELDS = AdErrorEnum.AdError.V(76)
        MISSING_TEMPLATE_FIELD_VALUE = AdErrorEnum.AdError.V(77)
        MISSING_TEXT = AdErrorEnum.AdError.V(78)
        MISSING_VISIBLE_URL = AdErrorEnum.AdError.V(79)
        MISSING_WIDTH = AdErrorEnum.AdError.V(80)
        MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED = AdErrorEnum.AdError.V(81)
        MUST_USE_TEMP_AD_UNION_ID_ON_ADD = AdErrorEnum.AdError.V(82)
        TOO_LONG = AdErrorEnum.AdError.V(83)
        TOO_SHORT = AdErrorEnum.AdError.V(84)
        UNION_DIMENSIONS_CANNOT_CHANGE = AdErrorEnum.AdError.V(85)
        UNKNOWN_ADDRESS_COMPONENT = AdErrorEnum.AdError.V(86)
        UNKNOWN_FIELD_NAME = AdErrorEnum.AdError.V(87)
        UNKNOWN_UNIQUE_NAME = AdErrorEnum.AdError.V(88)
        UNSUPPORTED_DIMENSIONS = AdErrorEnum.AdError.V(89)
        URL_INVALID_SCHEME = AdErrorEnum.AdError.V(90)
        URL_INVALID_TOP_LEVEL_DOMAIN = AdErrorEnum.AdError.V(91)
        URL_MALFORMED = AdErrorEnum.AdError.V(92)
        URL_NO_HOST = AdErrorEnum.AdError.V(93)
        URL_NOT_EQUIVALENT = AdErrorEnum.AdError.V(94)
        URL_HOST_NAME_TOO_LONG = AdErrorEnum.AdError.V(95)
        URL_NO_SCHEME = AdErrorEnum.AdError.V(96)
        URL_NO_TOP_LEVEL_DOMAIN = AdErrorEnum.AdError.V(97)
        URL_PATH_NOT_ALLOWED = AdErrorEnum.AdError.V(98)
        URL_PORT_NOT_ALLOWED = AdErrorEnum.AdError.V(99)
        URL_QUERY_NOT_ALLOWED = AdErrorEnum.AdError.V(100)
        URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG = AdErrorEnum.AdError.V(102)
        USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE = AdErrorEnum.AdError.V(103)
        INCONSISTENT_EXPANDABLE_SETTINGS = AdErrorEnum.AdError.V(104)
        INVALID_FORMAT = AdErrorEnum.AdError.V(105)
        INVALID_FIELD_TEXT = AdErrorEnum.AdError.V(106)
        ELEMENT_NOT_PRESENT = AdErrorEnum.AdError.V(107)
        IMAGE_ERROR = AdErrorEnum.AdError.V(108)
        VALUE_NOT_IN_RANGE = AdErrorEnum.AdError.V(109)
        FIELD_NOT_PRESENT = AdErrorEnum.AdError.V(110)
        ADDRESS_NOT_COMPLETE = AdErrorEnum.AdError.V(111)
        ADDRESS_INVALID = AdErrorEnum.AdError.V(112)
        VIDEO_RETRIEVAL_ERROR = AdErrorEnum.AdError.V(113)
        AUDIO_ERROR = AdErrorEnum.AdError.V(114)
        INVALID_YOUTUBE_DISPLAY_URL = AdErrorEnum.AdError.V(115)
        TOO_MANY_PRODUCT_IMAGES = AdErrorEnum.AdError.V(116)
        TOO_MANY_PRODUCT_VIDEOS = AdErrorEnum.AdError.V(117)
        INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE = AdErrorEnum.AdError.V(118)
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = AdErrorEnum.AdError.V(119)
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = AdErrorEnum.AdError.V(120)
        DISALLOWED_NUMBER_TYPE = AdErrorEnum.AdError.V(121)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = AdErrorEnum.AdError.V(122)
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
            AdErrorEnum.AdError.V(123)
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = AdErrorEnum.AdError.V(124)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = AdErrorEnum.AdError.V(125)
        INVALID_CALL_CONVERSION_TYPE_ID = AdErrorEnum.AdError.V(126)
        CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID = (
            AdErrorEnum.AdError.V(127)
        )
        CANNOT_SET_PATH2_WITHOUT_PATH1 = AdErrorEnum.AdError.V(128)
        MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME = AdErrorEnum.AdError.V(129)
        INCOMPATIBLE_WITH_RESTRICTION_TYPE = AdErrorEnum.AdError.V(130)
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = AdErrorEnum.AdError.V(131)
        MISSING_IMAGE_OR_MEDIA_BUNDLE = AdErrorEnum.AdError.V(132)
        PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN = AdErrorEnum.AdError.V(133)
        PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE = AdErrorEnum.AdError.V(134)
        PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE = (
            AdErrorEnum.AdError.V(135)
        )
        PLACEHOLDER_DEFAULT_VALUE_MISSING = AdErrorEnum.AdError.V(136)
        UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE = AdErrorEnum.AdError.V(137)
        AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT = AdErrorEnum.AdError.V(138)
        UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION = AdErrorEnum.AdError.V(139)
        TOO_MANY_AD_CUSTOMIZERS = AdErrorEnum.AdError.V(141)
        INVALID_AD_CUSTOMIZER_FORMAT = AdErrorEnum.AdError.V(142)
        NESTED_AD_CUSTOMIZER_SYNTAX = AdErrorEnum.AdError.V(143)
        UNSUPPORTED_AD_CUSTOMIZER_SYNTAX = AdErrorEnum.AdError.V(144)
        UNPAIRED_BRACE_IN_AD_CUSTOMIZER_TAG = AdErrorEnum.AdError.V(145)
        MORE_THAN_ONE_COUNTDOWN_TAG_TYPE_EXISTS = AdErrorEnum.AdError.V(146)
        DATE_TIME_IN_COUNTDOWN_TAG_IS_INVALID = AdErrorEnum.AdError.V(147)
        DATE_TIME_IN_COUNTDOWN_TAG_IS_PAST = AdErrorEnum.AdError.V(148)
        UNRECOGNIZED_AD_CUSTOMIZER_TAG_FOUND = AdErrorEnum.AdError.V(149)
    class AdError(metaclass=_AdError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdErrorEnum.AdError.V(0)
    UNKNOWN = AdErrorEnum.AdError.V(1)
    AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE = AdErrorEnum.AdError.V(2)
    APPROXIMATELY_TOO_LONG = AdErrorEnum.AdError.V(3)
    APPROXIMATELY_TOO_SHORT = AdErrorEnum.AdError.V(4)
    BAD_SNIPPET = AdErrorEnum.AdError.V(5)
    CANNOT_MODIFY_AD = AdErrorEnum.AdError.V(6)
    CANNOT_SET_BUSINESS_NAME_IF_URL_SET = AdErrorEnum.AdError.V(7)
    CANNOT_SET_FIELD = AdErrorEnum.AdError.V(8)
    CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET = AdErrorEnum.AdError.V(9)
    CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING = AdErrorEnum.AdError.V(10)
    CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE = AdErrorEnum.AdError.V(11)
    CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING = AdErrorEnum.AdError.V(12)
    CANNOT_SET_URL = AdErrorEnum.AdError.V(13)
    CANNOT_SET_WITHOUT_FINAL_URLS = AdErrorEnum.AdError.V(14)
    CANNOT_SET_WITH_FINAL_URLS = AdErrorEnum.AdError.V(15)
    CANNOT_SET_WITH_URL_DATA = AdErrorEnum.AdError.V(17)
    CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR = AdErrorEnum.AdError.V(18)
    CUSTOMER_NOT_APPROVED_MOBILEADS = AdErrorEnum.AdError.V(19)
    CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS = AdErrorEnum.AdError.V(20)
    CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS = AdErrorEnum.AdError.V(21)
    CUSTOMER_NOT_ELIGIBLE = AdErrorEnum.AdError.V(22)
    CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL = AdErrorEnum.AdError.V(23)
    DIMENSION_ALREADY_IN_UNION = AdErrorEnum.AdError.V(24)
    DIMENSION_MUST_BE_SET = AdErrorEnum.AdError.V(25)
    DIMENSION_NOT_IN_UNION = AdErrorEnum.AdError.V(26)
    DISPLAY_URL_CANNOT_BE_SPECIFIED = AdErrorEnum.AdError.V(27)
    DOMESTIC_PHONE_NUMBER_FORMAT = AdErrorEnum.AdError.V(28)
    EMERGENCY_PHONE_NUMBER = AdErrorEnum.AdError.V(29)
    EMPTY_FIELD = AdErrorEnum.AdError.V(30)
    FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID = AdErrorEnum.AdError.V(31)
    FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH = AdErrorEnum.AdError.V(32)
    ILLEGAL_AD_CUSTOMIZER_TAG_USE = AdErrorEnum.AdError.V(33)
    ILLEGAL_TAG_USE = AdErrorEnum.AdError.V(34)
    INCONSISTENT_DIMENSIONS = AdErrorEnum.AdError.V(35)
    INCONSISTENT_STATUS_IN_TEMPLATE_UNION = AdErrorEnum.AdError.V(36)
    INCORRECT_LENGTH = AdErrorEnum.AdError.V(37)
    INELIGIBLE_FOR_UPGRADE = AdErrorEnum.AdError.V(38)
    INVALID_AD_ADDRESS_CAMPAIGN_TARGET = AdErrorEnum.AdError.V(39)
    INVALID_AD_TYPE = AdErrorEnum.AdError.V(40)
    INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE = AdErrorEnum.AdError.V(41)
    INVALID_ATTRIBUTES_FOR_MOBILE_TEXT = AdErrorEnum.AdError.V(42)
    INVALID_CALL_TO_ACTION_TEXT = AdErrorEnum.AdError.V(43)
    INVALID_CHARACTER_FOR_URL = AdErrorEnum.AdError.V(44)
    INVALID_COUNTRY_CODE = AdErrorEnum.AdError.V(45)
    INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG = AdErrorEnum.AdError.V(47)
    INVALID_INPUT = AdErrorEnum.AdError.V(48)
    INVALID_MARKUP_LANGUAGE = AdErrorEnum.AdError.V(49)
    INVALID_MOBILE_CARRIER = AdErrorEnum.AdError.V(50)
    INVALID_MOBILE_CARRIER_TARGET = AdErrorEnum.AdError.V(51)
    INVALID_NUMBER_OF_ELEMENTS = AdErrorEnum.AdError.V(52)
    INVALID_PHONE_NUMBER_FORMAT = AdErrorEnum.AdError.V(53)
    INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID = AdErrorEnum.AdError.V(54)
    INVALID_TEMPLATE_DATA = AdErrorEnum.AdError.V(55)
    INVALID_TEMPLATE_ELEMENT_FIELD_TYPE = AdErrorEnum.AdError.V(56)
    INVALID_TEMPLATE_ID = AdErrorEnum.AdError.V(57)
    LINE_TOO_WIDE = AdErrorEnum.AdError.V(58)
    MISSING_AD_CUSTOMIZER_MAPPING = AdErrorEnum.AdError.V(59)
    MISSING_ADDRESS_COMPONENT = AdErrorEnum.AdError.V(60)
    MISSING_ADVERTISEMENT_NAME = AdErrorEnum.AdError.V(61)
    MISSING_BUSINESS_NAME = AdErrorEnum.AdError.V(62)
    MISSING_DESCRIPTION1 = AdErrorEnum.AdError.V(63)
    MISSING_DESCRIPTION2 = AdErrorEnum.AdError.V(64)
    MISSING_DESTINATION_URL_TAG = AdErrorEnum.AdError.V(65)
    MISSING_LANDING_PAGE_URL_TAG = AdErrorEnum.AdError.V(66)
    MISSING_DIMENSION = AdErrorEnum.AdError.V(67)
    MISSING_DISPLAY_URL = AdErrorEnum.AdError.V(68)
    MISSING_HEADLINE = AdErrorEnum.AdError.V(69)
    MISSING_HEIGHT = AdErrorEnum.AdError.V(70)
    MISSING_IMAGE = AdErrorEnum.AdError.V(71)
    MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS = AdErrorEnum.AdError.V(72)
    MISSING_MARKUP_LANGUAGES = AdErrorEnum.AdError.V(73)
    MISSING_MOBILE_CARRIER = AdErrorEnum.AdError.V(74)
    MISSING_PHONE = AdErrorEnum.AdError.V(75)
    MISSING_REQUIRED_TEMPLATE_FIELDS = AdErrorEnum.AdError.V(76)
    MISSING_TEMPLATE_FIELD_VALUE = AdErrorEnum.AdError.V(77)
    MISSING_TEXT = AdErrorEnum.AdError.V(78)
    MISSING_VISIBLE_URL = AdErrorEnum.AdError.V(79)
    MISSING_WIDTH = AdErrorEnum.AdError.V(80)
    MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED = AdErrorEnum.AdError.V(81)
    MUST_USE_TEMP_AD_UNION_ID_ON_ADD = AdErrorEnum.AdError.V(82)
    TOO_LONG = AdErrorEnum.AdError.V(83)
    TOO_SHORT = AdErrorEnum.AdError.V(84)
    UNION_DIMENSIONS_CANNOT_CHANGE = AdErrorEnum.AdError.V(85)
    UNKNOWN_ADDRESS_COMPONENT = AdErrorEnum.AdError.V(86)
    UNKNOWN_FIELD_NAME = AdErrorEnum.AdError.V(87)
    UNKNOWN_UNIQUE_NAME = AdErrorEnum.AdError.V(88)
    UNSUPPORTED_DIMENSIONS = AdErrorEnum.AdError.V(89)
    URL_INVALID_SCHEME = AdErrorEnum.AdError.V(90)
    URL_INVALID_TOP_LEVEL_DOMAIN = AdErrorEnum.AdError.V(91)
    URL_MALFORMED = AdErrorEnum.AdError.V(92)
    URL_NO_HOST = AdErrorEnum.AdError.V(93)
    URL_NOT_EQUIVALENT = AdErrorEnum.AdError.V(94)
    URL_HOST_NAME_TOO_LONG = AdErrorEnum.AdError.V(95)
    URL_NO_SCHEME = AdErrorEnum.AdError.V(96)
    URL_NO_TOP_LEVEL_DOMAIN = AdErrorEnum.AdError.V(97)
    URL_PATH_NOT_ALLOWED = AdErrorEnum.AdError.V(98)
    URL_PORT_NOT_ALLOWED = AdErrorEnum.AdError.V(99)
    URL_QUERY_NOT_ALLOWED = AdErrorEnum.AdError.V(100)
    URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG = AdErrorEnum.AdError.V(102)
    USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE = AdErrorEnum.AdError.V(103)
    INCONSISTENT_EXPANDABLE_SETTINGS = AdErrorEnum.AdError.V(104)
    INVALID_FORMAT = AdErrorEnum.AdError.V(105)
    INVALID_FIELD_TEXT = AdErrorEnum.AdError.V(106)
    ELEMENT_NOT_PRESENT = AdErrorEnum.AdError.V(107)
    IMAGE_ERROR = AdErrorEnum.AdError.V(108)
    VALUE_NOT_IN_RANGE = AdErrorEnum.AdError.V(109)
    FIELD_NOT_PRESENT = AdErrorEnum.AdError.V(110)
    ADDRESS_NOT_COMPLETE = AdErrorEnum.AdError.V(111)
    ADDRESS_INVALID = AdErrorEnum.AdError.V(112)
    VIDEO_RETRIEVAL_ERROR = AdErrorEnum.AdError.V(113)
    AUDIO_ERROR = AdErrorEnum.AdError.V(114)
    INVALID_YOUTUBE_DISPLAY_URL = AdErrorEnum.AdError.V(115)
    TOO_MANY_PRODUCT_IMAGES = AdErrorEnum.AdError.V(116)
    TOO_MANY_PRODUCT_VIDEOS = AdErrorEnum.AdError.V(117)
    INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE = AdErrorEnum.AdError.V(118)
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = AdErrorEnum.AdError.V(119)
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = AdErrorEnum.AdError.V(120)
    DISALLOWED_NUMBER_TYPE = AdErrorEnum.AdError.V(121)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = AdErrorEnum.AdError.V(122)
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = AdErrorEnum.AdError.V(
        123
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = AdErrorEnum.AdError.V(124)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = AdErrorEnum.AdError.V(125)
    INVALID_CALL_CONVERSION_TYPE_ID = AdErrorEnum.AdError.V(126)
    CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID = AdErrorEnum.AdError.V(
        127
    )
    CANNOT_SET_PATH2_WITHOUT_PATH1 = AdErrorEnum.AdError.V(128)
    MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME = AdErrorEnum.AdError.V(129)
    INCOMPATIBLE_WITH_RESTRICTION_TYPE = AdErrorEnum.AdError.V(130)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = AdErrorEnum.AdError.V(131)
    MISSING_IMAGE_OR_MEDIA_BUNDLE = AdErrorEnum.AdError.V(132)
    PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN = AdErrorEnum.AdError.V(133)
    PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE = AdErrorEnum.AdError.V(134)
    PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE = AdErrorEnum.AdError.V(
        135
    )
    PLACEHOLDER_DEFAULT_VALUE_MISSING = AdErrorEnum.AdError.V(136)
    UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE = AdErrorEnum.AdError.V(137)
    AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT = AdErrorEnum.AdError.V(138)
    UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION = AdErrorEnum.AdError.V(139)
    TOO_MANY_AD_CUSTOMIZERS = AdErrorEnum.AdError.V(141)
    INVALID_AD_CUSTOMIZER_FORMAT = AdErrorEnum.AdError.V(142)
    NESTED_AD_CUSTOMIZER_SYNTAX = AdErrorEnum.AdError.V(143)
    UNSUPPORTED_AD_CUSTOMIZER_SYNTAX = AdErrorEnum.AdError.V(144)
    UNPAIRED_BRACE_IN_AD_CUSTOMIZER_TAG = AdErrorEnum.AdError.V(145)
    MORE_THAN_ONE_COUNTDOWN_TAG_TYPE_EXISTS = AdErrorEnum.AdError.V(146)
    DATE_TIME_IN_COUNTDOWN_TAG_IS_INVALID = AdErrorEnum.AdError.V(147)
    DATE_TIME_IN_COUNTDOWN_TAG_IS_PAST = AdErrorEnum.AdError.V(148)
    UNRECOGNIZED_AD_CUSTOMIZER_TAG_FOUND = AdErrorEnum.AdError.V(149)
    def __init__(
        self,
    ) -> None: ...

global___AdErrorEnum = AdErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.served_asset_field_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdTextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    PINNED_FIELD_FIELD_NUMBER: builtins.int
    pinned_field: google.ads.google_ads.v4.proto.enums.served_asset_field_type_pb2.ServedAssetFieldTypeEnum.ServedAssetFieldType.V = (
        ...
    )
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        pinned_field: google.ads.google_ads.v4.proto.enums.served_asset_field_type_pb2.ServedAssetFieldTypeEnum.ServedAssetFieldType.V = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "pinned_field", b"pinned_field", "text", b"text"
        ],
    ) -> None: ...

global___AdTextAsset = AdTextAsset

class AdImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    @property
    def asset(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        asset: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> None: ...

global___AdImageAsset = AdImageAsset

class AdVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    @property
    def asset(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        asset: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> None: ...

global___AdVideoAsset = AdVideoAsset

class AdMediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    @property
    def asset(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        asset: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> None: ...

global___AdMediaBundleAsset = AdMediaBundleAsset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.asset_types_pb2
import google.ads.google_ads.v6.proto.common.policy_pb2
import google.ads.google_ads.v6.proto.enums.asset_type_pb2
import google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2
import google.ads.google_ads.v6.proto.enums.policy_review_status_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Asset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    POLICY_SUMMARY_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_ASSET_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_ASSET_FIELD_NUMBER: builtins.int
    IMAGE_ASSET_FIELD_NUMBER: builtins.int
    TEXT_ASSET_FIELD_NUMBER: builtins.int
    LEAD_FORM_ASSET_FIELD_NUMBER: builtins.int
    BOOK_ON_GOOGLE_ASSET_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    type: google.ads.google_ads.v6.proto.enums.asset_type_pb2.AssetTypeEnum.AssetType.V = (
        ...
    )
    final_urls: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    @property
    def policy_summary(self) -> global___AssetPolicySummary: ...
    @property
    def youtube_video_asset(
        self,
    ) -> google.ads.google_ads.v6.proto.common.asset_types_pb2.YoutubeVideoAsset: ...
    @property
    def media_bundle_asset(
        self,
    ) -> google.ads.google_ads.v6.proto.common.asset_types_pb2.MediaBundleAsset: ...
    @property
    def image_asset(
        self,
    ) -> google.ads.google_ads.v6.proto.common.asset_types_pb2.ImageAsset: ...
    @property
    def text_asset(
        self,
    ) -> google.ads.google_ads.v6.proto.common.asset_types_pb2.TextAsset: ...
    @property
    def lead_form_asset(
        self,
    ) -> google.ads.google_ads.v6.proto.common.asset_types_pb2.LeadFormAsset: ...
    @property
    def book_on_google_asset(
        self,
    ) -> google.ads.google_ads.v6.proto.common.asset_types_pb2.BookOnGoogleAsset: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        type: google.ads.google_ads.v6.proto.enums.asset_type_pb2.AssetTypeEnum.AssetType.V = ...,
        final_urls: typing.Optional[typing.Iterable[typing.Text]] = ...,
        policy_summary: typing.Optional[global___AssetPolicySummary] = ...,
        youtube_video_asset: typing.Optional[
            google.ads.google_ads.v6.proto.common.asset_types_pb2.YoutubeVideoAsset
        ] = ...,
        media_bundle_asset: typing.Optional[
            google.ads.google_ads.v6.proto.common.asset_types_pb2.MediaBundleAsset
        ] = ...,
        image_asset: typing.Optional[
            google.ads.google_ads.v6.proto.common.asset_types_pb2.ImageAsset
        ] = ...,
        text_asset: typing.Optional[
            google.ads.google_ads.v6.proto.common.asset_types_pb2.TextAsset
        ] = ...,
        lead_form_asset: typing.Optional[
            google.ads.google_ads.v6.proto.common.asset_types_pb2.LeadFormAsset
        ] = ...,
        book_on_google_asset: typing.Optional[
            google.ads.google_ads.v6.proto.common.asset_types_pb2.BookOnGoogleAsset
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "asset_data",
            b"asset_data",
            "book_on_google_asset",
            b"book_on_google_asset",
            "id",
            b"id",
            "image_asset",
            b"image_asset",
            "lead_form_asset",
            b"lead_form_asset",
            "media_bundle_asset",
            b"media_bundle_asset",
            "name",
            b"name",
            "policy_summary",
            b"policy_summary",
            "text_asset",
            b"text_asset",
            "youtube_video_asset",
            b"youtube_video_asset",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "asset_data",
            b"asset_data",
            "book_on_google_asset",
            b"book_on_google_asset",
            "final_urls",
            b"final_urls",
            "id",
            b"id",
            "image_asset",
            b"image_asset",
            "lead_form_asset",
            b"lead_form_asset",
            "media_bundle_asset",
            b"media_bundle_asset",
            "name",
            b"name",
            "policy_summary",
            b"policy_summary",
            "resource_name",
            b"resource_name",
            "text_asset",
            b"text_asset",
            "type",
            b"type",
            "youtube_video_asset",
            b"youtube_video_asset",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["asset_data", b"asset_data"]
    ) -> typing_extensions.Literal[
        "youtube_video_asset",
        "media_bundle_asset",
        "image_asset",
        "text_asset",
        "lead_form_asset",
        "book_on_google_asset",
    ]: ...

global___Asset = Asset

class AssetPolicySummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POLICY_TOPIC_ENTRIES_FIELD_NUMBER: builtins.int
    REVIEW_STATUS_FIELD_NUMBER: builtins.int
    APPROVAL_STATUS_FIELD_NUMBER: builtins.int
    review_status: google.ads.google_ads.v6.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = (
        ...
    )
    approval_status: google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = (
        ...
    )
    @property
    def policy_topic_entries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.policy_pb2.PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.policy_pb2.PolicyTopicEntry
            ]
        ] = ...,
        review_status: google.ads.google_ads.v6.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = ...,
        approval_status: google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

global___AssetPolicySummary = AssetPolicySummary



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.resources.customer_manager_link_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetCustomerManagerLinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetCustomerManagerLinkRequest = GetCustomerManagerLinkRequest

class MutateCustomerManagerLinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CustomerManagerLinkOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[
            typing.Iterable[global___CustomerManagerLinkOperation]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "operations", b"operations"
        ],
    ) -> None: ...

global___MutateCustomerManagerLinkRequest = MutateCustomerManagerLinkRequest

class MoveManagerLinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    PREVIOUS_CUSTOMER_MANAGER_LINK_FIELD_NUMBER: builtins.int
    NEW_MANAGER_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    previous_customer_manager_link: typing.Text = ...
    new_manager: typing.Text = ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        previous_customer_manager_link: typing.Text = ...,
        new_manager: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "new_manager",
            b"new_manager",
            "previous_customer_manager_link",
            b"previous_customer_manager_link",
        ],
    ) -> None: ...

global___MoveManagerLinkRequest = MoveManagerLinkRequest

class CustomerManagerLinkOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def update(
        self,
    ) -> google.ads.google_ads.v5.proto.resources.customer_manager_link_pb2.CustomerManagerLink: ...
    def __init__(
        self,
        *,
        update_mask: typing.Optional[google.protobuf.field_mask_pb2.FieldMask] = ...,
        update: typing.Optional[
            google.ads.google_ads.v5.proto.resources.customer_manager_link_pb2.CustomerManagerLink
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "operation",
            b"operation",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "operation",
            b"operation",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["update"]: ...

global___CustomerManagerLinkOperation = CustomerManagerLinkOperation

class MutateCustomerManagerLinkResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MutateCustomerManagerLinkResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[
            typing.Iterable[global___MutateCustomerManagerLinkResult]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["results", b"results"]
    ) -> None: ...

global___MutateCustomerManagerLinkResponse = MutateCustomerManagerLinkResponse

class MoveManagerLinkResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MoveManagerLinkResponse = MoveManagerLinkResponse

class MutateCustomerManagerLinkResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateCustomerManagerLinkResult = MutateCustomerManagerLinkResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.merchant_center_link_pb2
import grpc

from .merchant_center_link_service_pb2 import *

class MerchantCenterLinkServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def ListMerchantCenterLinks(
        self,
        request: global___ListMerchantCenterLinksRequest,
    ) -> global___ListMerchantCenterLinksResponse: ...
    def GetMerchantCenterLink(
        self,
        request: global___GetMerchantCenterLinkRequest,
    ) -> google.ads.google_ads.v5.proto.resources.merchant_center_link_pb2.MerchantCenterLink: ...
    def MutateMerchantCenterLink(
        self,
        request: global___MutateMerchantCenterLinkRequest,
    ) -> global___MutateMerchantCenterLinkResponse: ...

class MerchantCenterLinkServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListMerchantCenterLinks(
        self,
        request: global___ListMerchantCenterLinksRequest,
        context: grpc.ServicerContext,
    ) -> global___ListMerchantCenterLinksResponse: ...
    @abc.abstractmethod
    def GetMerchantCenterLink(
        self,
        request: global___GetMerchantCenterLinkRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.merchant_center_link_pb2.MerchantCenterLink: ...
    @abc.abstractmethod
    def MutateMerchantCenterLink(
        self,
        request: global___MutateMerchantCenterLinkRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateMerchantCenterLinkResponse: ...

def add_MerchantCenterLinkServiceServicer_to_server(
    servicer: MerchantCenterLinkServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BatchJobErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BatchJobError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BatchJobError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BatchJobErrorEnum.BatchJobError.V(0)
        UNKNOWN = BatchJobErrorEnum.BatchJobError.V(1)
        CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING = BatchJobErrorEnum.BatchJobError.V(
            2
        )
        EMPTY_OPERATIONS = BatchJobErrorEnum.BatchJobError.V(3)
        INVALID_SEQUENCE_TOKEN = BatchJobErrorEnum.BatchJobError.V(4)
        RESULTS_NOT_READY = BatchJobErrorEnum.BatchJobError.V(5)
        INVALID_PAGE_SIZE = BatchJobErrorEnum.BatchJobError.V(6)
        CAN_ONLY_REMOVE_PENDING_JOB = BatchJobErrorEnum.BatchJobError.V(7)
    class BatchJobError(metaclass=_BatchJobError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BatchJobErrorEnum.BatchJobError.V(0)
    UNKNOWN = BatchJobErrorEnum.BatchJobError.V(1)
    CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING = BatchJobErrorEnum.BatchJobError.V(2)
    EMPTY_OPERATIONS = BatchJobErrorEnum.BatchJobError.V(3)
    INVALID_SEQUENCE_TOKEN = BatchJobErrorEnum.BatchJobError.V(4)
    RESULTS_NOT_READY = BatchJobErrorEnum.BatchJobError.V(5)
    INVALID_PAGE_SIZE = BatchJobErrorEnum.BatchJobError.V(6)
    CAN_ONLY_REMOVE_PENDING_JOB = BatchJobErrorEnum.BatchJobError.V(7)
    def __init__(
        self,
    ) -> None: ...

global___BatchJobErrorEnum = BatchJobErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.conversion_action_pb2
import grpc

from .conversion_action_service_pb2 import *

class ConversionActionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetConversionAction(
        self,
        request: global___GetConversionActionRequest,
    ) -> google.ads.google_ads.v6.proto.resources.conversion_action_pb2.ConversionAction: ...
    def MutateConversionActions(
        self,
        request: global___MutateConversionActionsRequest,
    ) -> global___MutateConversionActionsResponse: ...

class ConversionActionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetConversionAction(
        self,
        request: global___GetConversionActionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.conversion_action_pb2.ConversionAction: ...
    @abc.abstractmethod
    def MutateConversionActions(
        self,
        request: global___MutateConversionActionsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateConversionActionsResponse: ...

def add_ConversionActionServiceServicer_to_server(
    servicer: ConversionActionServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PromotionPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PromotionPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PromotionPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(0)
        UNKNOWN = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(1)
        PROMOTION_TARGET = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(2)
        DISCOUNT_MODIFIER = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(3)
        PERCENT_OFF = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(4)
        MONEY_AMOUNT_OFF = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(5)
        PROMOTION_CODE = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(6)
        ORDERS_OVER_AMOUNT = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(
            7
        )
        PROMOTION_START = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(8)
        PROMOTION_END = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(9)
        OCCASION = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(10)
        FINAL_URLS = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(11)
        FINAL_MOBILE_URLS = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(
            12
        )
        TRACKING_URL = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(13)
        LANGUAGE = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(14)
        FINAL_URL_SUFFIX = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(15)
    class PromotionPlaceholderField(metaclass=_PromotionPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(0)
    UNKNOWN = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(1)
    PROMOTION_TARGET = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(2)
    DISCOUNT_MODIFIER = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(3)
    PERCENT_OFF = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(4)
    MONEY_AMOUNT_OFF = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(5)
    PROMOTION_CODE = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(6)
    ORDERS_OVER_AMOUNT = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(7)
    PROMOTION_START = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(8)
    PROMOTION_END = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(9)
    OCCASION = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(10)
    FINAL_URLS = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(11)
    FINAL_MOBILE_URLS = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(12)
    TRACKING_URL = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(13)
    LANGUAGE = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(14)
    FINAL_URL_SUFFIX = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(15)
    def __init__(
        self,
    ) -> None: ...

global___PromotionPlaceholderFieldEnum = PromotionPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def key(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def value(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        key: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        value: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]
    ) -> None: ...

global___CustomParameter = CustomParameter



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SitelinkPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SitelinkPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            SitelinkPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(0)
        UNKNOWN = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(1)
        TEXT = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(2)
        LINE_1 = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(3)
        LINE_2 = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(4)
        FINAL_URLS = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(5)
        FINAL_MOBILE_URLS = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(6)
        TRACKING_URL = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(7)
        FINAL_URL_SUFFIX = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(8)
    class SitelinkPlaceholderField(metaclass=_SitelinkPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(0)
    UNKNOWN = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(1)
    TEXT = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(2)
    LINE_1 = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(3)
    LINE_2 = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(4)
    FINAL_URLS = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(5)
    FINAL_MOBILE_URLS = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(6)
    TRACKING_URL = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(7)
    FINAL_URL_SUFFIX = SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V(8)
    def __init__(
        self,
    ) -> None: ...

global___SitelinkPlaceholderFieldEnum = SitelinkPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.keyword_plan_competition_level_pb2
import google.ads.google_ads.v6.proto.enums.month_of_year_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanHistoricalMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVG_MONTHLY_SEARCHES_FIELD_NUMBER: builtins.int
    MONTHLY_SEARCH_VOLUMES_FIELD_NUMBER: builtins.int
    COMPETITION_FIELD_NUMBER: builtins.int
    COMPETITION_INDEX_FIELD_NUMBER: builtins.int
    LOW_TOP_OF_PAGE_BID_MICROS_FIELD_NUMBER: builtins.int
    HIGH_TOP_OF_PAGE_BID_MICROS_FIELD_NUMBER: builtins.int
    avg_monthly_searches: builtins.int = ...
    competition: google.ads.google_ads.v6.proto.enums.keyword_plan_competition_level_pb2.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel.V = (
        ...
    )
    competition_index: builtins.int = ...
    low_top_of_page_bid_micros: builtins.int = ...
    high_top_of_page_bid_micros: builtins.int = ...
    @property
    def monthly_search_volumes(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MonthlySearchVolume
    ]: ...
    def __init__(
        self,
        *,
        avg_monthly_searches: builtins.int = ...,
        monthly_search_volumes: typing.Optional[
            typing.Iterable[global___MonthlySearchVolume]
        ] = ...,
        competition: google.ads.google_ads.v6.proto.enums.keyword_plan_competition_level_pb2.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel.V = ...,
        competition_index: builtins.int = ...,
        low_top_of_page_bid_micros: builtins.int = ...,
        high_top_of_page_bid_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_avg_monthly_searches",
            b"_avg_monthly_searches",
            "_competition_index",
            b"_competition_index",
            "_high_top_of_page_bid_micros",
            b"_high_top_of_page_bid_micros",
            "_low_top_of_page_bid_micros",
            b"_low_top_of_page_bid_micros",
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_avg_monthly_searches",
            b"_avg_monthly_searches",
            "_competition_index",
            b"_competition_index",
            "_high_top_of_page_bid_micros",
            b"_high_top_of_page_bid_micros",
            "_low_top_of_page_bid_micros",
            b"_low_top_of_page_bid_micros",
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition",
            b"competition",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
            "monthly_search_volumes",
            b"monthly_search_volumes",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_avg_monthly_searches", b"_avg_monthly_searches"
        ],
    ) -> typing_extensions.Literal["avg_monthly_searches"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_competition_index", b"_competition_index"
        ],
    ) -> typing_extensions.Literal["competition_index"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_high_top_of_page_bid_micros", b"_high_top_of_page_bid_micros"
        ],
    ) -> typing_extensions.Literal["high_top_of_page_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_low_top_of_page_bid_micros", b"_low_top_of_page_bid_micros"
        ],
    ) -> typing_extensions.Literal["low_top_of_page_bid_micros"]: ...

global___KeywordPlanHistoricalMetrics = KeywordPlanHistoricalMetrics

class MonthlySearchVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    MONTHLY_SEARCHES_FIELD_NUMBER: builtins.int
    year: builtins.int = ...
    month: google.ads.google_ads.v6.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = (
        ...
    )
    monthly_searches: builtins.int = ...
    def __init__(
        self,
        *,
        year: builtins.int = ...,
        month: google.ads.google_ads.v6.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = ...,
        monthly_searches: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_monthly_searches",
            b"_monthly_searches",
            "_year",
            b"_year",
            "monthly_searches",
            b"monthly_searches",
            "year",
            b"year",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_monthly_searches",
            b"_monthly_searches",
            "_year",
            b"_year",
            "month",
            b"month",
            "monthly_searches",
            b"monthly_searches",
            "year",
            b"year",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_monthly_searches", b"_monthly_searches"
        ],
    ) -> typing_extensions.Literal["monthly_searches"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_year", b"_year"]
    ) -> typing_extensions.Literal["year"]: ...

global___MonthlySearchVolume = MonthlySearchVolume



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .conversion_upload_service_pb2 import *

class ConversionUploadServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def UploadClickConversions(
        self,
        request: global___UploadClickConversionsRequest,
    ) -> global___UploadClickConversionsResponse: ...
    def UploadCallConversions(
        self,
        request: global___UploadCallConversionsRequest,
    ) -> global___UploadCallConversionsResponse: ...

class ConversionUploadServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadClickConversions(
        self,
        request: global___UploadClickConversionsRequest,
        context: grpc.ServicerContext,
    ) -> global___UploadClickConversionsResponse: ...
    @abc.abstractmethod
    def UploadCallConversions(
        self,
        request: global___UploadCallConversionsRequest,
        context: grpc.ServicerContext,
    ) -> global___UploadCallConversionsResponse: ...

def add_ConversionUploadServiceServicer_to_server(
    servicer: ConversionUploadServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.custom_parameter_pb2
import google.ads.google_ads.v5.proto.common.explorer_auto_optimizer_setting_pb2
import google.ads.google_ads.v5.proto.common.targeting_setting_pb2
import google.ads.google_ads.v5.proto.enums.ad_group_ad_rotation_mode_pb2
import google.ads.google_ads.v5.proto.enums.ad_group_status_pb2
import google.ads.google_ads.v5.proto.enums.ad_group_type_pb2
import google.ads.google_ads.v5.proto.enums.bidding_source_pb2
import google.ads.google_ads.v5.proto.enums.targeting_dimension_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    AD_ROTATION_MODE_FIELD_NUMBER: builtins.int
    BASE_AD_GROUP_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    CPM_BID_MICROS_FIELD_NUMBER: builtins.int
    TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
    CPV_BID_MICROS_FIELD_NUMBER: builtins.int
    TARGET_CPM_MICROS_FIELD_NUMBER: builtins.int
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    PERCENT_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    EXPLORER_AUTO_OPTIMIZER_SETTING_FIELD_NUMBER: builtins.int
    DISPLAY_CUSTOM_BID_DIMENSION_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    TARGETING_SETTING_FIELD_NUMBER: builtins.int
    EFFECTIVE_TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
    EFFECTIVE_TARGET_CPA_SOURCE_FIELD_NUMBER: builtins.int
    EFFECTIVE_TARGET_ROAS_FIELD_NUMBER: builtins.int
    EFFECTIVE_TARGET_ROAS_SOURCE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.ad_group_status_pb2.AdGroupStatusEnum.AdGroupStatus.V = (
        ...
    )
    type: google.ads.google_ads.v5.proto.enums.ad_group_type_pb2.AdGroupTypeEnum.AdGroupType.V = (
        ...
    )
    ad_rotation_mode: google.ads.google_ads.v5.proto.enums.ad_group_ad_rotation_mode_pb2.AdGroupAdRotationModeEnum.AdGroupAdRotationMode.V = (
        ...
    )
    base_ad_group: typing.Text = ...
    tracking_url_template: typing.Text = ...
    campaign: typing.Text = ...
    cpc_bid_micros: builtins.int = ...
    cpm_bid_micros: builtins.int = ...
    target_cpa_micros: builtins.int = ...
    cpv_bid_micros: builtins.int = ...
    target_cpm_micros: builtins.int = ...
    target_roas: builtins.float = ...
    percent_cpc_bid_micros: builtins.int = ...
    display_custom_bid_dimension: google.ads.google_ads.v5.proto.enums.targeting_dimension_pb2.TargetingDimensionEnum.TargetingDimension.V = (
        ...
    )
    final_url_suffix: typing.Text = ...
    effective_target_cpa_micros: builtins.int = ...
    effective_target_cpa_source: google.ads.google_ads.v5.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = (
        ...
    )
    effective_target_roas: builtins.float = ...
    effective_target_roas_source: google.ads.google_ads.v5.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = (
        ...
    )
    labels: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def explorer_auto_optimizer_setting(
        self,
    ) -> google.ads.google_ads.v5.proto.common.explorer_auto_optimizer_setting_pb2.ExplorerAutoOptimizerSetting: ...
    @property
    def targeting_setting(
        self,
    ) -> google.ads.google_ads.v5.proto.common.targeting_setting_pb2.TargetingSetting: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        status: google.ads.google_ads.v5.proto.enums.ad_group_status_pb2.AdGroupStatusEnum.AdGroupStatus.V = ...,
        type: google.ads.google_ads.v5.proto.enums.ad_group_type_pb2.AdGroupTypeEnum.AdGroupType.V = ...,
        ad_rotation_mode: google.ads.google_ads.v5.proto.enums.ad_group_ad_rotation_mode_pb2.AdGroupAdRotationModeEnum.AdGroupAdRotationMode.V = ...,
        base_ad_group: typing.Text = ...,
        tracking_url_template: typing.Text = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        campaign: typing.Text = ...,
        cpc_bid_micros: builtins.int = ...,
        cpm_bid_micros: builtins.int = ...,
        target_cpa_micros: builtins.int = ...,
        cpv_bid_micros: builtins.int = ...,
        target_cpm_micros: builtins.int = ...,
        target_roas: builtins.float = ...,
        percent_cpc_bid_micros: builtins.int = ...,
        explorer_auto_optimizer_setting: typing.Optional[
            google.ads.google_ads.v5.proto.common.explorer_auto_optimizer_setting_pb2.ExplorerAutoOptimizerSetting
        ] = ...,
        display_custom_bid_dimension: google.ads.google_ads.v5.proto.enums.targeting_dimension_pb2.TargetingDimensionEnum.TargetingDimension.V = ...,
        final_url_suffix: typing.Text = ...,
        targeting_setting: typing.Optional[
            google.ads.google_ads.v5.proto.common.targeting_setting_pb2.TargetingSetting
        ] = ...,
        effective_target_cpa_micros: builtins.int = ...,
        effective_target_cpa_source: google.ads.google_ads.v5.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = ...,
        effective_target_roas: builtins.float = ...,
        effective_target_roas_source: google.ads.google_ads.v5.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = ...,
        labels: typing.Optional[typing.Iterable[typing.Text]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_base_ad_group",
            b"_base_ad_group",
            "_campaign",
            b"_campaign",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_cpm_bid_micros",
            b"_cpm_bid_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_effective_target_cpa_micros",
            b"_effective_target_cpa_micros",
            "_effective_target_roas",
            b"_effective_target_roas",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_target_cpm_micros",
            b"_target_cpm_micros",
            "_target_roas",
            b"_target_roas",
            "_tracking_url_template",
            b"_tracking_url_template",
            "base_ad_group",
            b"base_ad_group",
            "campaign",
            b"campaign",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "cpm_bid_micros",
            b"cpm_bid_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "effective_target_cpa_micros",
            b"effective_target_cpa_micros",
            "effective_target_roas",
            b"effective_target_roas",
            "explorer_auto_optimizer_setting",
            b"explorer_auto_optimizer_setting",
            "final_url_suffix",
            b"final_url_suffix",
            "id",
            b"id",
            "name",
            b"name",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "target_cpa_micros",
            b"target_cpa_micros",
            "target_cpm_micros",
            b"target_cpm_micros",
            "target_roas",
            b"target_roas",
            "targeting_setting",
            b"targeting_setting",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_base_ad_group",
            b"_base_ad_group",
            "_campaign",
            b"_campaign",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_cpm_bid_micros",
            b"_cpm_bid_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_effective_target_cpa_micros",
            b"_effective_target_cpa_micros",
            "_effective_target_roas",
            b"_effective_target_roas",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_target_cpm_micros",
            b"_target_cpm_micros",
            "_target_roas",
            b"_target_roas",
            "_tracking_url_template",
            b"_tracking_url_template",
            "ad_rotation_mode",
            b"ad_rotation_mode",
            "base_ad_group",
            b"base_ad_group",
            "campaign",
            b"campaign",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "cpm_bid_micros",
            b"cpm_bid_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "display_custom_bid_dimension",
            b"display_custom_bid_dimension",
            "effective_target_cpa_micros",
            b"effective_target_cpa_micros",
            "effective_target_cpa_source",
            b"effective_target_cpa_source",
            "effective_target_roas",
            b"effective_target_roas",
            "effective_target_roas_source",
            b"effective_target_roas_source",
            "explorer_auto_optimizer_setting",
            b"explorer_auto_optimizer_setting",
            "final_url_suffix",
            b"final_url_suffix",
            "id",
            b"id",
            "labels",
            b"labels",
            "name",
            b"name",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target_cpa_micros",
            b"target_cpa_micros",
            "target_cpm_micros",
            b"target_cpm_micros",
            "target_roas",
            b"target_roas",
            "targeting_setting",
            b"targeting_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_base_ad_group", b"_base_ad_group"],
    ) -> typing_extensions.Literal["base_ad_group"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_cpc_bid_micros", b"_cpc_bid_micros"],
    ) -> typing_extensions.Literal["cpc_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_cpm_bid_micros", b"_cpm_bid_micros"],
    ) -> typing_extensions.Literal["cpm_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_cpv_bid_micros", b"_cpv_bid_micros"],
    ) -> typing_extensions.Literal["cpv_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_effective_target_cpa_micros", b"_effective_target_cpa_micros"
        ],
    ) -> typing_extensions.Literal["effective_target_cpa_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_effective_target_roas", b"_effective_target_roas"
        ],
    ) -> typing_extensions.Literal["effective_target_roas"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_final_url_suffix", b"_final_url_suffix"
        ],
    ) -> typing_extensions.Literal["final_url_suffix"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_percent_cpc_bid_micros", b"_percent_cpc_bid_micros"
        ],
    ) -> typing_extensions.Literal["percent_cpc_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_target_cpa_micros", b"_target_cpa_micros"
        ],
    ) -> typing_extensions.Literal["target_cpa_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_target_cpm_micros", b"_target_cpm_micros"
        ],
    ) -> typing_extensions.Literal["target_cpm_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions.Literal["target_roas"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions.Literal["tracking_url_template"]: ...

global___AdGroup = AdGroup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.user_lists_pb2
import google.ads.google_ads.v4.proto.enums.access_reason_pb2
import google.ads.google_ads.v4.proto.enums.user_list_access_status_pb2
import google.ads.google_ads.v4.proto.enums.user_list_closing_reason_pb2
import google.ads.google_ads.v4.proto.enums.user_list_membership_status_pb2
import google.ads.google_ads.v4.proto.enums.user_list_size_range_pb2
import google.ads.google_ads.v4.proto.enums.user_list_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MEMBERSHIP_STATUS_FIELD_NUMBER: builtins.int
    INTEGRATION_CODE_FIELD_NUMBER: builtins.int
    MEMBERSHIP_LIFE_SPAN_FIELD_NUMBER: builtins.int
    SIZE_FOR_DISPLAY_FIELD_NUMBER: builtins.int
    SIZE_RANGE_FOR_DISPLAY_FIELD_NUMBER: builtins.int
    SIZE_FOR_SEARCH_FIELD_NUMBER: builtins.int
    SIZE_RANGE_FOR_SEARCH_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CLOSING_REASON_FIELD_NUMBER: builtins.int
    ACCESS_REASON_FIELD_NUMBER: builtins.int
    ACCOUNT_USER_LIST_STATUS_FIELD_NUMBER: builtins.int
    ELIGIBLE_FOR_SEARCH_FIELD_NUMBER: builtins.int
    ELIGIBLE_FOR_DISPLAY_FIELD_NUMBER: builtins.int
    CRM_BASED_USER_LIST_FIELD_NUMBER: builtins.int
    SIMILAR_USER_LIST_FIELD_NUMBER: builtins.int
    RULE_BASED_USER_LIST_FIELD_NUMBER: builtins.int
    LOGICAL_USER_LIST_FIELD_NUMBER: builtins.int
    BASIC_USER_LIST_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    membership_status: google.ads.google_ads.v4.proto.enums.user_list_membership_status_pb2.UserListMembershipStatusEnum.UserListMembershipStatus.V = (
        ...
    )
    size_range_for_display: google.ads.google_ads.v4.proto.enums.user_list_size_range_pb2.UserListSizeRangeEnum.UserListSizeRange.V = (
        ...
    )
    size_range_for_search: google.ads.google_ads.v4.proto.enums.user_list_size_range_pb2.UserListSizeRangeEnum.UserListSizeRange.V = (
        ...
    )
    type: google.ads.google_ads.v4.proto.enums.user_list_type_pb2.UserListTypeEnum.UserListType.V = (
        ...
    )
    closing_reason: google.ads.google_ads.v4.proto.enums.user_list_closing_reason_pb2.UserListClosingReasonEnum.UserListClosingReason.V = (
        ...
    )
    access_reason: google.ads.google_ads.v4.proto.enums.access_reason_pb2.AccessReasonEnum.AccessReason.V = (
        ...
    )
    account_user_list_status: google.ads.google_ads.v4.proto.enums.user_list_access_status_pb2.UserListAccessStatusEnum.UserListAccessStatus.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def read_only(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def description(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def integration_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def membership_life_span(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def size_for_display(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def size_for_search(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def eligible_for_search(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def eligible_for_display(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def crm_based_user_list(
        self,
    ) -> google.ads.google_ads.v4.proto.common.user_lists_pb2.CrmBasedUserListInfo: ...
    @property
    def similar_user_list(
        self,
    ) -> google.ads.google_ads.v4.proto.common.user_lists_pb2.SimilarUserListInfo: ...
    @property
    def rule_based_user_list(
        self,
    ) -> google.ads.google_ads.v4.proto.common.user_lists_pb2.RuleBasedUserListInfo: ...
    @property
    def logical_user_list(
        self,
    ) -> google.ads.google_ads.v4.proto.common.user_lists_pb2.LogicalUserListInfo: ...
    @property
    def basic_user_list(
        self,
    ) -> google.ads.google_ads.v4.proto.common.user_lists_pb2.BasicUserListInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        read_only: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        description: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        membership_status: google.ads.google_ads.v4.proto.enums.user_list_membership_status_pb2.UserListMembershipStatusEnum.UserListMembershipStatus.V = ...,
        integration_code: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        membership_life_span: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        size_for_display: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        size_range_for_display: google.ads.google_ads.v4.proto.enums.user_list_size_range_pb2.UserListSizeRangeEnum.UserListSizeRange.V = ...,
        size_for_search: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        size_range_for_search: google.ads.google_ads.v4.proto.enums.user_list_size_range_pb2.UserListSizeRangeEnum.UserListSizeRange.V = ...,
        type: google.ads.google_ads.v4.proto.enums.user_list_type_pb2.UserListTypeEnum.UserListType.V = ...,
        closing_reason: google.ads.google_ads.v4.proto.enums.user_list_closing_reason_pb2.UserListClosingReasonEnum.UserListClosingReason.V = ...,
        access_reason: google.ads.google_ads.v4.proto.enums.access_reason_pb2.AccessReasonEnum.AccessReason.V = ...,
        account_user_list_status: google.ads.google_ads.v4.proto.enums.user_list_access_status_pb2.UserListAccessStatusEnum.UserListAccessStatus.V = ...,
        eligible_for_search: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        eligible_for_display: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        crm_based_user_list: typing.Optional[
            google.ads.google_ads.v4.proto.common.user_lists_pb2.CrmBasedUserListInfo
        ] = ...,
        similar_user_list: typing.Optional[
            google.ads.google_ads.v4.proto.common.user_lists_pb2.SimilarUserListInfo
        ] = ...,
        rule_based_user_list: typing.Optional[
            google.ads.google_ads.v4.proto.common.user_lists_pb2.RuleBasedUserListInfo
        ] = ...,
        logical_user_list: typing.Optional[
            google.ads.google_ads.v4.proto.common.user_lists_pb2.LogicalUserListInfo
        ] = ...,
        basic_user_list: typing.Optional[
            google.ads.google_ads.v4.proto.common.user_lists_pb2.BasicUserListInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "basic_user_list",
            b"basic_user_list",
            "crm_based_user_list",
            b"crm_based_user_list",
            "description",
            b"description",
            "eligible_for_display",
            b"eligible_for_display",
            "eligible_for_search",
            b"eligible_for_search",
            "id",
            b"id",
            "integration_code",
            b"integration_code",
            "logical_user_list",
            b"logical_user_list",
            "membership_life_span",
            b"membership_life_span",
            "name",
            b"name",
            "read_only",
            b"read_only",
            "rule_based_user_list",
            b"rule_based_user_list",
            "similar_user_list",
            b"similar_user_list",
            "size_for_display",
            b"size_for_display",
            "size_for_search",
            b"size_for_search",
            "user_list",
            b"user_list",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "access_reason",
            b"access_reason",
            "account_user_list_status",
            b"account_user_list_status",
            "basic_user_list",
            b"basic_user_list",
            "closing_reason",
            b"closing_reason",
            "crm_based_user_list",
            b"crm_based_user_list",
            "description",
            b"description",
            "eligible_for_display",
            b"eligible_for_display",
            "eligible_for_search",
            b"eligible_for_search",
            "id",
            b"id",
            "integration_code",
            b"integration_code",
            "logical_user_list",
            b"logical_user_list",
            "membership_life_span",
            b"membership_life_span",
            "membership_status",
            b"membership_status",
            "name",
            b"name",
            "read_only",
            b"read_only",
            "resource_name",
            b"resource_name",
            "rule_based_user_list",
            b"rule_based_user_list",
            "similar_user_list",
            b"similar_user_list",
            "size_for_display",
            b"size_for_display",
            "size_for_search",
            b"size_for_search",
            "size_range_for_display",
            b"size_range_for_display",
            "size_range_for_search",
            b"size_range_for_search",
            "type",
            b"type",
            "user_list",
            b"user_list",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["user_list", b"user_list"]
    ) -> typing_extensions.Literal[
        "crm_based_user_list",
        "similar_user_list",
        "rule_based_user_list",
        "logical_user_list",
        "basic_user_list",
    ]: ...

global___UserList = UserList



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.affiliate_location_feed_relationship_type_pb2
import google.ads.google_ads.v4.proto.enums.feed_attribute_type_pb2
import google.ads.google_ads.v4.proto.enums.feed_origin_pb2
import google.ads.google_ads.v4.proto.enums.feed_status_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Feed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class PlacesLocationFeedData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class OAuthInfo(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            HTTP_METHOD_FIELD_NUMBER: builtins.int
            HTTP_REQUEST_URL_FIELD_NUMBER: builtins.int
            HTTP_AUTHORIZATION_HEADER_FIELD_NUMBER: builtins.int
            @property
            def http_method(self) -> google.protobuf.wrappers_pb2.StringValue: ...
            @property
            def http_request_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
            @property
            def http_authorization_header(
                self,
            ) -> google.protobuf.wrappers_pb2.StringValue: ...
            def __init__(
                self,
                *,
                http_method: typing.Optional[
                    google.protobuf.wrappers_pb2.StringValue
                ] = ...,
                http_request_url: typing.Optional[
                    google.protobuf.wrappers_pb2.StringValue
                ] = ...,
                http_authorization_header: typing.Optional[
                    google.protobuf.wrappers_pb2.StringValue
                ] = ...,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing_extensions.Literal[
                    "http_authorization_header",
                    b"http_authorization_header",
                    "http_method",
                    b"http_method",
                    "http_request_url",
                    b"http_request_url",
                ],
            ) -> builtins.bool: ...
            def ClearField(
                self,
                field_name: typing_extensions.Literal[
                    "http_authorization_header",
                    b"http_authorization_header",
                    "http_method",
                    b"http_method",
                    "http_request_url",
                    b"http_request_url",
                ],
            ) -> None: ...
        OAUTH_INFO_FIELD_NUMBER: builtins.int
        EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
        BUSINESS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
        BUSINESS_NAME_FILTER_FIELD_NUMBER: builtins.int
        CATEGORY_FILTERS_FIELD_NUMBER: builtins.int
        LABEL_FILTERS_FIELD_NUMBER: builtins.int
        @property
        def oauth_info(self) -> global___Feed.PlacesLocationFeedData.OAuthInfo: ...
        @property
        def email_address(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def business_account_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def business_name_filter(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def category_filters(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        @property
        def label_filters(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            oauth_info: typing.Optional[
                global___Feed.PlacesLocationFeedData.OAuthInfo
            ] = ...,
            email_address: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            business_account_id: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            business_name_filter: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            category_filters: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
            label_filters: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "business_account_id",
                b"business_account_id",
                "business_name_filter",
                b"business_name_filter",
                "email_address",
                b"email_address",
                "oauth_info",
                b"oauth_info",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "business_account_id",
                b"business_account_id",
                "business_name_filter",
                b"business_name_filter",
                "category_filters",
                b"category_filters",
                "email_address",
                b"email_address",
                "label_filters",
                b"label_filters",
                "oauth_info",
                b"oauth_info",
            ],
        ) -> None: ...
    class AffiliateLocationFeedData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CHAIN_IDS_FIELD_NUMBER: builtins.int
        RELATIONSHIP_TYPE_FIELD_NUMBER: builtins.int
        relationship_type: google.ads.google_ads.v4.proto.enums.affiliate_location_feed_relationship_type_pb2.AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipType.V = (
            ...
        )
        @property
        def chain_ids(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.Int64Value
        ]: ...
        def __init__(
            self,
            *,
            chain_ids: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.Int64Value]
            ] = ...,
            relationship_type: google.ads.google_ads.v4.proto.enums.affiliate_location_feed_relationship_type_pb2.AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipType.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "chain_ids", b"chain_ids", "relationship_type", b"relationship_type"
            ],
        ) -> None: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_OPERATIONS_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PLACES_LOCATION_FEED_DATA_FIELD_NUMBER: builtins.int
    AFFILIATE_LOCATION_FEED_DATA_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    origin: google.ads.google_ads.v4.proto.enums.feed_origin_pb2.FeedOriginEnum.FeedOrigin.V = (
        ...
    )
    status: google.ads.google_ads.v4.proto.enums.feed_status_pb2.FeedStatusEnum.FeedStatus.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def attributes(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___FeedAttribute
    ]: ...
    @property
    def attribute_operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___FeedAttributeOperation
    ]: ...
    @property
    def places_location_feed_data(self) -> global___Feed.PlacesLocationFeedData: ...
    @property
    def affiliate_location_feed_data(
        self,
    ) -> global___Feed.AffiliateLocationFeedData: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        attributes: typing.Optional[typing.Iterable[global___FeedAttribute]] = ...,
        attribute_operations: typing.Optional[
            typing.Iterable[global___FeedAttributeOperation]
        ] = ...,
        origin: google.ads.google_ads.v4.proto.enums.feed_origin_pb2.FeedOriginEnum.FeedOrigin.V = ...,
        status: google.ads.google_ads.v4.proto.enums.feed_status_pb2.FeedStatusEnum.FeedStatus.V = ...,
        places_location_feed_data: typing.Optional[
            global___Feed.PlacesLocationFeedData
        ] = ...,
        affiliate_location_feed_data: typing.Optional[
            global___Feed.AffiliateLocationFeedData
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "affiliate_location_feed_data",
            b"affiliate_location_feed_data",
            "id",
            b"id",
            "name",
            b"name",
            "places_location_feed_data",
            b"places_location_feed_data",
            "system_feed_generation_data",
            b"system_feed_generation_data",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "affiliate_location_feed_data",
            b"affiliate_location_feed_data",
            "attribute_operations",
            b"attribute_operations",
            "attributes",
            b"attributes",
            "id",
            b"id",
            "name",
            b"name",
            "origin",
            b"origin",
            "places_location_feed_data",
            b"places_location_feed_data",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "system_feed_generation_data",
            b"system_feed_generation_data",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "system_feed_generation_data", b"system_feed_generation_data"
        ],
    ) -> typing_extensions.Literal[
        "places_location_feed_data", "affiliate_location_feed_data"
    ]: ...

global___Feed = Feed

class FeedAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    IS_PART_OF_KEY_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v4.proto.enums.feed_attribute_type_pb2.FeedAttributeTypeEnum.FeedAttributeType.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def is_part_of_key(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        type: google.ads.google_ads.v4.proto.enums.feed_attribute_type_pb2.FeedAttributeTypeEnum.FeedAttributeType.V = ...,
        is_part_of_key: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "id", b"id", "is_part_of_key", b"is_part_of_key", "name", b"name"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "id",
            b"id",
            "is_part_of_key",
            b"is_part_of_key",
            "name",
            b"name",
            "type",
            b"type",
        ],
    ) -> None: ...

global___FeedAttribute = FeedAttribute

class FeedAttributeOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _Operator(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Operator.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedAttributeOperation.Operator.V(0)
        UNKNOWN = FeedAttributeOperation.Operator.V(1)
        ADD = FeedAttributeOperation.Operator.V(2)
    class Operator(metaclass=_Operator):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedAttributeOperation.Operator.V(0)
    UNKNOWN = FeedAttributeOperation.Operator.V(1)
    ADD = FeedAttributeOperation.Operator.V(2)

    OPERATOR_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    operator: global___FeedAttributeOperation.Operator.V = ...
    @property
    def value(self) -> global___FeedAttribute: ...
    def __init__(
        self,
        *,
        operator: global___FeedAttributeOperation.Operator.V = ...,
        value: typing.Optional[global___FeedAttribute] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["value", b"value"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "operator", b"operator", "value", b"value"
        ],
    ) -> None: ...

global___FeedAttributeOperation = FeedAttributeOperation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AssetError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetErrorEnum.AssetError.V(0)
        UNKNOWN = AssetErrorEnum.AssetError.V(1)
        CUSTOMER_NOT_ON_ALLOWLIST_FOR_ASSET_TYPE = AssetErrorEnum.AssetError.V(13)
        DUPLICATE_ASSET = AssetErrorEnum.AssetError.V(3)
        DUPLICATE_ASSET_NAME = AssetErrorEnum.AssetError.V(4)
        ASSET_DATA_IS_MISSING = AssetErrorEnum.AssetError.V(5)
        CANNOT_MODIFY_ASSET_NAME = AssetErrorEnum.AssetError.V(6)
        FIELD_INCOMPATIBLE_WITH_ASSET_TYPE = AssetErrorEnum.AssetError.V(7)
        INVALID_CALL_TO_ACTION_TEXT = AssetErrorEnum.AssetError.V(8)
        LEAD_FORM_INVALID_FIELDS_COMBINATION = AssetErrorEnum.AssetError.V(9)
        LEAD_FORM_MISSING_AGREEMENT = AssetErrorEnum.AssetError.V(10)
        INVALID_ASSET_STATUS = AssetErrorEnum.AssetError.V(11)
        FIELD_CANNOT_BE_MODIFIED_FOR_ASSET_TYPE = AssetErrorEnum.AssetError.V(12)
    class AssetError(metaclass=_AssetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetErrorEnum.AssetError.V(0)
    UNKNOWN = AssetErrorEnum.AssetError.V(1)
    CUSTOMER_NOT_ON_ALLOWLIST_FOR_ASSET_TYPE = AssetErrorEnum.AssetError.V(13)
    DUPLICATE_ASSET = AssetErrorEnum.AssetError.V(3)
    DUPLICATE_ASSET_NAME = AssetErrorEnum.AssetError.V(4)
    ASSET_DATA_IS_MISSING = AssetErrorEnum.AssetError.V(5)
    CANNOT_MODIFY_ASSET_NAME = AssetErrorEnum.AssetError.V(6)
    FIELD_INCOMPATIBLE_WITH_ASSET_TYPE = AssetErrorEnum.AssetError.V(7)
    INVALID_CALL_TO_ACTION_TEXT = AssetErrorEnum.AssetError.V(8)
    LEAD_FORM_INVALID_FIELDS_COMBINATION = AssetErrorEnum.AssetError.V(9)
    LEAD_FORM_MISSING_AGREEMENT = AssetErrorEnum.AssetError.V(10)
    INVALID_ASSET_STATUS = AssetErrorEnum.AssetError.V(11)
    FIELD_CANNOT_BE_MODIFIED_FOR_ASSET_TYPE = AssetErrorEnum.AssetError.V(12)
    def __init__(
        self,
    ) -> None: ...

global___AssetErrorEnum = AssetErrorEnum
